.. _spkg_cmr:

cmr: Combinatorial matrix recognition
===============================================

Description
-----------

The following matrix classes can be recognized:

- Totally Unimodular Matrices
- Network Matrices
- Complement Totally Unimodular Matrices
- (Strongly) k-Modular and Unimodular Matrices

Moreover, representation matrices for the following matroid classes can be recognized:

- Regular Matroids
- Graphic / Cographic / Planar Matrices
- Series-Parallel Matroids


License
-------

MIT license


Upstream Contact
----------------

https://discopt.github.io/cmr/

https://github.com/discopt/cmr

Type
----

optional


Dependencies
------------

- :ref:`spkg_cmake`
- :ref:`spkg_googletest`

Version Information
-------------------

package-version.txt::

    acfda4fe72cb73eb68a7ed20ebfcf4fdb3027542


Equivalent System Packages
--------------------------

(none known)

